@@ -226,9 +226,9 @@ GSwitchItAppletStateCallback (XklStateChange changeType,
 	XklDebug (150, "group is now %d, restore: %d\n", group, restore);
 
 	if (changeType == GROUP_CHANGED) {
-		GSwitchItPluginManagerGroupChanged (&globals.pluginManager,
-						    group);
 		ForAllApplets ()
+			GSwitchItPluginManagerGroupChanged (&globals.pluginManager, 
+					sia->notebook, group);
 			XklDebug (200, "do repaint\n");
 			GSwitchItAppletRevalidateGroup (sia, group);
 		NextApplet
@@ -291,7 +291,7 @@ GSwitchItAppletPrepareDrawing (GSwitchItApplet * sia, int group)
 	GdkPixbuf *image;
 	GdkPixbuf *scaled;
 	PanelAppletOrient orient;
-	int psize, xsize = 0, ysize = 0;
+	int psize, isize, xsize = 0, ysize = 0, xsize1 = 0, ysize1 = 0;
 	double xyratio;
 	pimage = g_slist_nth_data (globals.appletConfig.images, group);
 	sia->ebox = gtk_event_box_new ();
@@ -303,22 +303,29 @@ GSwitchItAppletPrepareDrawing (GSwitchItApplet * sia, int group)
 		orient =
 		    panel_applet_get_orient (PANEL_APPLET (sia->applet));
 		psize =
-		    panel_applet_get_size (PANEL_APPLET (sia->applet)) - 4;
-		XklDebug (150, "Resizing the applet for size %d\n", psize);
+		    panel_applet_get_size (PANEL_APPLET (sia->applet));
+		isize = psize - 4;
 		xyratio =
 		    1.0 * gdk_pixbuf_get_width (image) /
 		    gdk_pixbuf_get_height (image);
 		switch (orient) {
 		case PANEL_APPLET_ORIENT_UP:
 		case PANEL_APPLET_ORIENT_DOWN:
-			ysize = psize;
-			xsize = psize * xyratio;
+			ysize = isize;
+			xsize = isize * xyratio;
+			ysize1 = psize;
+			xsize1 = psize * xyratio;
 			break;
 		case PANEL_APPLET_ORIENT_LEFT:
 		case PANEL_APPLET_ORIENT_RIGHT:
-			ysize = psize / xyratio;
+			xsize = isize;
+			ysize = isize / xyratio;
+			xsize1 = psize;
+			ysize1 = psize / xyratio;
 			break;
 		}
+		XklDebug (150, "Resizing the applet for size %d: %d X %d\n", isize, xsize, ysize);
+		XklDebug (150, "Would be %d: %d X %d\n", psize, xsize1, ysize1);
 
 		scaled =
 		    gdk_pixbuf_scale_simple (image, xsize, ysize,
@@ -327,6 +334,10 @@ GSwitchItAppletPrepareDrawing (GSwitchItApplet * sia, int group)
 		gtk_container_add (GTK_CONTAINER (sia->ebox), flagImg);
 		g_object_unref (G_OBJECT (scaled));
 	} else {
+		gpointer pcounter = NULL; 
+		char *prevLayoutName = NULL;
+		char *labelTitle = NULL;
+		int counter = 0;
 		char *layoutName = NULL;
 		XklConfigItem configItem;
 		GtkWidget *align, *label;
@@ -363,10 +374,6 @@ GSwitchItAppletPrepareDrawing (GSwitchItApplet * sia, int group)
 		if (layoutName == NULL)
 			layoutName = g_strdup ("?");
 
-		gpointer pcounter = NULL; 
-		char *prevLayoutName = NULL;
-		char *labelTitle = NULL;
-		int counter = 0;
 		if (g_hash_table_lookup_extended (shortDescrs, layoutName, 
 						  (gpointer*)&prevLayoutName, &pcounter))
 		{
@@ -434,12 +441,9 @@ GSwitchItAppletFillNotebook (GSwitchItApplet * sia)
 								globals.groupNames,
 								grp),
 							  &globals.kbdConfig);
+		page = decoratedPage == NULL ? page : decoratedPage;
 
-		gtk_notebook_append_page (notebook,
-					  decoratedPage ==
-					  NULL ? page : decoratedPage,
-					  gtk_label_new (""));
-
+		gtk_notebook_append_page (notebook, page, NULL);
 		gtk_widget_show_all (page);
 	}
 }
@@ -546,6 +550,10 @@ GSwitchItAppletButtonPressed (GtkWidget *
 			      GdkEventButton *
 			      event, GSwitchItAppletConfig * config)
 {
+	GtkWidget * img = gtk_bin_get_child (GTK_BIN (widget));
+	XklDebug (150, "Flag img size %d x %d\n", 
+			img->allocation.width,
+			img->allocation.height);
 	if (event->button == 1 && event->type == GDK_BUTTON_PRESS) {
 		XklDebug (150, "Mouse button pressed on applet\n");
 		GSwitchItConfigLockNextGroup ();
@@ -597,6 +605,12 @@ GSwitchItAppletCmdPreview (BonoboUIComponent *
 	static KeyboardDrawingGroupLevel groupsLevels[] = { {0,1}, {0,3}, {0,0}, {0,2} };
 	static KeyboardDrawingGroupLevel * pGroupsLevels[] = {
 		groupsLevels, groupsLevels + 1, groupsLevels + 2, groupsLevels + 3 };
+#ifdef HAVE_XKB
+	GladeXML *gladeData;
+	GtkWidget *dialog, *kbdraw;
+	XkbComponentNamesRec componentNames;
+	XklConfigRec xklData;
+#endif
 	XklState *xklState = XklGetCurrentState ();
 	gpointer p = g_hash_table_lookup (globals.previewDialogs, GINT_TO_POINTER (xklState->group));
 	if (p != NULL)
@@ -606,11 +620,9 @@ GSwitchItAppletCmdPreview (BonoboUIComponent *
 		return;
 	}
 #ifdef HAVE_XKB
-	GladeXML *gladeData = glade_xml_new (GNOME_GLADEDIR "/gswitchit.glade", "gswitchit_layout_view", NULL);
-        GtkWidget *dialog =
-        	glade_xml_get_widget (gladeData, "gswitchit_layout_view");
-	GtkWidget *kbdraw = keyboard_drawing_new ();
-	XkbComponentNamesRec componentNames;
+	gladeData = glade_xml_new (GNOME_GLADEDIR "/gswitchit.glade", "gswitchit_layout_view", NULL);
+        dialog = glade_xml_get_widget (gladeData, "gswitchit_layout_view");
+	kbdraw = keyboard_drawing_new ();
 
 	if (xklState->group >= 0 && 
 	    xklState->group < g_slist_length (globals.groupNames))
@@ -624,7 +636,6 @@ GSwitchItAppletCmdPreview (BonoboUIComponent *
 
   	keyboard_drawing_set_groups_levels (KEYBOARD_DRAWING (kbdraw), pGroupsLevels);
 
-	XklConfigRec xklData;
 	XklConfigRecInit (&xklData);
       	if (XklConfigGetFromServer (&xklData))
 	{
