@@ -20,7 +20,12 @@
 #ifndef __STICKYNOTES_APPLET_H__
 #define __STICKYNOTES_APPLET_H__
 
-#include <gnome.h>
+#include <gdk/gdkscreen.h>
+#include <gdk-pixbuf/gdk-pixbuf.h>
+#include <gtk/gtkadjustment.h>
+#include <gtk/gtktooltips.h>
+#include <gtk/gtkwidget.h>
+#include <glade/glade-xml.h>
 #include <panel-applet.h>
 #include <gconf/gconf-client.h>
 #include <glade/glade.h>
@@ -85,9 +90,7 @@ typedef struct
 	gint panel_size;
 	PanelAppletOrient panel_orient;
 	
-	GtkWidget *popup_menu;			/* Popup Menu */
 	GtkWidget *menu_tip;
-	GtkWidget *menu_show;
 } StickyNotesApplet;
 	
 typedef enum
@@ -113,4 +116,6 @@ void stickynotes_applet_update_tooltips(void);
 
 void stickynotes_applet_do_default_action(GdkScreen *screen);
 
+void stickynotes_applet_panel_icon_get_geometry (int *x, int *y, int *width, int *height);
+
 #endif /* __STICKYNOTES_APPLET_H__ */
